pub fn touch(path: impl AsRef<Path>) -> Result<()>Expand description
Similar to the unix touch command, this function updates the timestamp of a file to the current time.
If the file does not exist, it is created if the parent directory exists. If the file does not exist and the
parent directory does not exist, an error is returned.